'''
Author: BDFD
Date: 2021-10-27 18:42:57
LastEditTime: 2021-10-27 21:23:36
LastEditors: Please set LastEditors
Description: In User Settings Edit
FilePath: \6.0-PyPI_Missing_Value_Table\src\missing_value_table\main.py
'''


def add_one(x):
    return 12 * x + 1
